==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/libs/srba/include/mrpt/srba/landmark_render_models.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

#pragma once

#include <mrpt/utils/TColor.h>

namespace mrpt { namespace srba {

	/** @name Possible types for LANDMARK_TYPE::render_mode_t, used to control how a landmark is rendered 
	    @{ */

	/** Render 2D/3D point landmarks. */
	struct landmark_rendering_as_point 
	{   /** Parameters to be merged with RbaEngine<>::TOpenGLRepresentationOptions */
		struct TOpenGLRepresentationOptionsExtra
		{
		};
	};

	/** Render "fake graph-slam-like landmarks" as keyframe-to-keyframe constraints. */
	struct landmark_rendering_as_pose_constraints 
	{   /** Parameters to be merged with RbaEngine<>::TOpenGLRepresentationOptions */
		struct TOpenGLRepresentationOptionsExtra
		{
		};
	};

	/** Not to be rendered. */
	struct landmark_rendering_none 
	{   /** Parameters to be merged with RbaEngine<>::TOpenGLRepresentationOptions */
		struct TOpenGLRepresentationOptionsExtra
		{
		};
	};

	/** @} */

} } // end NS

==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/libs/srba/include/mrpt/srba/landmark_render_models.h <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

#pragma once

#include <mrpt/utils/TColor.h>

namespace mrpt { namespace srba {

	/** @name Possible types for LANDMARK_TYPE::render_mode_t, used to control how a landmark is rendered 
	    @{ */

	/** Render 2D/3D point landmarks. */
	struct landmark_rendering_as_point 
	{   /** Parameters to be merged with RbaEngine<>::TOpenGLRepresentationOptions */
		struct TOpenGLRepresentationOptionsExtra
		{
		};
	};

	/** Render "fake graph-slam-like landmarks" as keyframe-to-keyframe constraints. */
	struct landmark_rendering_as_pose_constraints 
	{   /** Parameters to be merged with RbaEngine<>::TOpenGLRepresentationOptions */
		struct TOpenGLRepresentationOptionsExtra
		{
		};
	};

	/** Not to be rendered. */
	struct landmark_rendering_none 
	{   /** Parameters to be merged with RbaEngine<>::TOpenGLRepresentationOptions */
		struct TOpenGLRepresentationOptionsExtra
		{
		};
	};

	/** @} */

} } // end NS
